==> claroline-1.8.11.tbz: www/claroline/claroline/lang/thai/locale_settings.php <==
<?php // $Id: locale_settings.php 9707 2007-12-12 13:46:31Z mlaurent $
/**
 * CLAROLINE
 *
 * @version 1.8 $Revision: 9707 $
 *
 * @copyright (c) 2001-2006 Universite catholique de Louvain (UCL)
 *
 * @author: claro team <cvs@claroline.net>
 *
 * @package LANG-TH
 */
/*оѲк .ЪԴ Գص ѹ 23 Ҥ 2549  
ҨШҢԪŻ ԷҪѯѹ Ѫɡ ࢵبѡ  10900.
Thai Developer & Translation : Assistant Professor Prachid Tinnabutr : Instructor of Division of Art , Chandrakasem Rajabhat University,Jatuchak,Bangkok ,Thailand.10900. http://artnet.chandra.ac.th
Last update:27-feb-2007 .

Personal Address : 144/157 Moo 1 ,Changwatana Rd.Pakkret District ,Nonthaburi Province,Thailand,11120 Tel/Fax:(66)0 2962 9505 prachid@prachid.com,prachid@wittycomputer.com ,Mobile Phone:(66)08 9667 0091
URL : http://www.prachid.com, http://www.wittycomputer.com, http://www.e107thailand.com
*/

$iso639_1_code = "th";
$iso639_2_code = "tha";

unset($langNameOfLang);
unset($langDay_of_weekNames);
unset($langMonthNames);

$langNameOfLang['arabic']        = "arabian";
$langNameOfLang['brazilian']     = "brazilian";
$langNameOfLang['bulgarian']     = "bulgarian";
$langNameOfLang['catalan']       = "catalan";
$langNameOfLang['croatian']      = "croatian";
$langNameOfLang['danish']        = "danish";
$langNameOfLang['dutch']         = "dutch";
$langNameOfLang['english']       = "english";
$langNameOfLang['finnish']       = "finnish";
$langNameOfLang['french']        = "french";
$langNameOfLang['galician']      = "galician";
$langNameOfLang['german']        = "german";
$langNameOfLang['greek']         = "greek";
$langNameOfLang['italian']       = "italian";
$langNameOfLang['indonesian']    = "indonesian";
$langNameOfLang['japanese']      = "japanese";
$langNameOfLang['malay']         = "malay";
$langNameOfLang['polish']        = "polish";
$langNameOfLang['portuguese']    = "portuguese";
$langNameOfLang['russian']       = "russian";
$langNameOfLang['simpl_chinese'] = "simplified chinese";
$langNameOfLang['slovenian']     = "slovenian";
$langNameOfLang['spanish']       = "spanish";
$langNameOfLang['swedish']       = "swedish";
$langNameOfLang['thai']          = "thai";
$langNameOfLang['turkish']       = "turkish";
$langNameOfLang['vietnamese']    = "vietnamese";
$langNameOfLang['zh_tw']         = "traditional chinese";

$charset = 'ISO-8859-11';
$text_dir = 'ltr';
$left_font_family = 'MS Sans Serif,Tahoma,verdana, helvetica, arial, geneva, sans-serif';
$right_font_family = 'MS Sans Serif,Tahoma, verdana, helvetica, arial, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
$byteUnits = array('Bytes', 'KB', 'MB', 'GB');

$langDay_of_weekNames['init'] = array('S', 'M', 'T', 'W', 'T', 'F', 'S');
$langDay_of_weekNames['short'] = array('', '', '', '', '', '', '');
$langDay_of_weekNames['long'] = array('ѹҷԵ', 'ѹѹ', 'ѹѧ', 'ѹظ', 'ѹʺ', 'ѹء', 'ѹ');

$langMonthNames['init']  = array('͹Ҥ', '͹Ҿѹ', '͹չҤ',  '͹¹', '͹Ҥ', '͹Զع¹', '͹áҤ', '͹ԧҤ', '͹ѹ¹', '͹Ҥ', '͹Ȩԡ¹', '͹ѹҤ');
$langMonthNames['short'] = array('͹Ҥ', '͹Ҿѹ', '͹չҤ',  '͹¹', '͹Ҥ', '͹Զع¹', '͹áҤ', '͹ԧҤ', '͹ѹ¹', '͹Ҥ', '͹Ȩԡ¹', '͹ѹҤ');
$langMonthNames['long'] = array('͹Ҥ', '͹Ҿѹ', '͹չҤ',  '͹¹', '͹Ҥ', '͹Զع¹', '͹áҤ', '͹ԧҤ', '͹ѹ¹', '͹Ҥ', '͹Ȩԡ¹', '͹ѹҤ');

$dateFormatShort =  "%b %d, %y";
$dateFormatLong  = '%A %B %d, %Y';
$dateTimeFormatLong  = '%B %d, %Y at %I:%M %p';
$dateTimeFormatShort = "%b. %d, %y %I:%M %p";
$timeNoSecFormat = '%I:%M %p';

?>

==> claroline-1.9.3.tbz: www/claroline/claroline/lang/thai/locale_settings.php <==
<?php // $Id: locale_settings.php 11495 2009-01-07 10:22:13Z fragile_be $
/**
 * CLAROLINE
 *
 * @version 1.8 $Revision: 11495 $
 *
 * @copyright (c) 2001-2006 Universite catholique de Louvain (UCL)
 *
 * @author: claro team <cvs@claroline.net>
 *
 * @package LANG-TH
 */
/*оѲк .ЪԴ Գص Ѻѹ 23 Ҥ 2549  Ѻاش 1 Ҥ 2552
ҨШҢԪŻ ԷҪѯѹ Ѫɡ ࢵبѡ  10900.
Thai Developer & Translation : Assistant Professor Prachid Tinnabutr : Division of Fine and Applied Arts : Faculty of Humanities and Social Sciences, Chandrakasem Rajabhat University,Jatuchak District,Bangkok ,Thailand.10900.
http://artnet.chandra.ac.th , http://www.chandra.ac.th
Last update:1 -Jan-2009.

Personal Address : 144/157 Moo 1 ,Changwatana Rd.Pakkret District ,Nonthaburi Province,Thailand,11120 Tel/Fax:(66)0 2962 9505 prachid@prachid.com,prachid@wittycomputer.com ,Mobile Phone:(66)08 9667 0091
URL : http://www.prachid.com, http://www.wittycomputer.com, http://www.e107thailand.com, http//www.clarolinethai.info
*/
$iso639_1_code = "th";
$iso639_2_code = "tha";

unset($langNameOfLang);
unset($langDay_of_weekNames);
unset($langMonthNames);

$langNameOfLang['arabic']        = "arabian";
$langNameOfLang['brazilian']     = "brazilian";
$langNameOfLang['bulgarian']     = "bulgarian";
$langNameOfLang['catalan']       = "catalan";
$langNameOfLang['croatian']      = "croatian";
$langNameOfLang['danish']        = "danish";
$langNameOfLang['dutch']         = "dutch";
$langNameOfLang['english']       = "english";
$langNameOfLang['finnish']       = "finnish";
$langNameOfLang['french']        = "french";
$langNameOfLang['galician']      = "galician";
$langNameOfLang['german']        = "german";
$langNameOfLang['greek']         = "greek";
$langNameOfLang['italian']       = "italian";
$langNameOfLang['indonesian']    = "indonesian";
$langNameOfLang['japanese']      = "japanese";
$langNameOfLang['malay']         = "malay";
$langNameOfLang['polish']        = "polish";
$langNameOfLang['portuguese']    = "portuguese";
$langNameOfLang['russian']       = "russian";
$langNameOfLang['simpl_chinese'] = "simplified chinese";
$langNameOfLang['slovenian']     = "slovenian";
$langNameOfLang['spanish']       = "spanish";
$langNameOfLang['swedish']       = "swedish";
$langNameOfLang['thai']          = "thai";
$langNameOfLang['turkish']       = "turkish";
$langNameOfLang['vietnamese']    = "vietnamese";
$langNameOfLang['zh_tw']         = "traditional chinese";

$charset = 'UTF-8';
$text_dir = 'ltr';
$left_font_family = 'MS Sans Serif,Tahoma,verdana, helvetica, arial, geneva, sans-serif';
$right_font_family = 'MS Sans Serif,Tahoma, verdana, helvetica, arial, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
$byteUnits = array('Bytes', 'KB', 'MB', 'GB');

$langDay_of_weekNames['init'] = array('S', 'M', 'T', 'W', 'T', 'F', 'S');
$langDay_of_weekNames['short'] = array('', '', '', '', '', '', '');
$langDay_of_weekNames['long'] = array('ѹҷԵ', 'ѹѹ', 'ѹѧ', 'ѹظ', 'ѹʺ', 'ѹء', 'ѹ');

$langMonthNames['init']  = array('͹Ҥ', '͹Ҿѹ', '͹չҤ',  '͹¹', '͹Ҥ', '͹Զع¹', '͹áҤ', '͹ԧҤ', '͹ѹ¹', '͹Ҥ', '͹Ȩԡ¹', '͹ѹҤ');
$langMonthNames['short'] = array('͹Ҥ', '͹Ҿѹ', '͹չҤ',  '͹¹', '͹Ҥ', '͹Զع¹', '͹áҤ', '͹ԧҤ', '͹ѹ¹', '͹Ҥ', '͹Ȩԡ¹', '͹ѹҤ');
$langMonthNames['long'] = array('͹Ҥ', '͹Ҿѹ', '͹չҤ',  '͹¹', '͹Ҥ', '͹Զع¹', '͹áҤ', '͹ԧҤ', '͹ѹ¹', '͹Ҥ', '͹Ȩԡ¹', '͹ѹҤ');

$dateFormatShort =  "%b %d, %y";
$dateFormatLong  = '%A %B %d, %Y';
$dateTimeFormatLong  = '%B %d, %Y at %I:%M %p';
$dateTimeFormatShort = "%b. %d, %y %I:%M %p";
$timeNoSecFormat = '%I:%M %p';

?>
